function f=coaxAlpha(epsilonR, muR, delta, sigma, outerD, innerD, freq)
% coaxAlpha(epsilonR, muR, delta, sigma, outerD, innerD, freq) 
%				- attenuation constant of coaxial cable
%  epsilonR - relative dielectric constant of dialectric (1 for air)
%  muR - relative permeability of dialectric (1 for air)
%  delta - dielectric loss
%  sigma - conductance of conductor material, per unit lenght 1/ohm*meter)
%  outerD - diameter of outer coax (meter)
%  innerD diameter of inner conductor (meter)
%  freq - frequency of signal

f=real(coaxGamma(epsilonR, muR, delta, sigma, outerD, innerD, freq));
